@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKOANDI_AGENTSEARCHINTERFACE_P_H
-#define AKOANDI_AGENTSEARCHINTERFACE_P_H
+#pragma once
 
 #include "agentsearchinterface.h"
 #include "collection.h"
@@ -39,4 +38,3 @@ private:
 
 }
 
-#endif
