@@ -66,7 +66,7 @@ class AgentConfigurationBasePrivate;
  * value must match the name of the @p X-Akonadi-Identifier value from the agent's
  * desktop file.
  *
- * The plugin binary should be installed into akonadi/config subdirectory in one
+ * The plugin binary should be installed into pim<version>/akonadi/config subdirectory in one
  * of the paths search by QCoreApplication::libraryPaths().
  */
 
@@ -139,7 +139,7 @@ protected:
     /**
      * Returns identifier of the Akonadi agent instance currently being configured.
      */
-    QString identifier() const;
+    Q_REQUIRED_RESULT QString identifier() const;
 
     /**
      * When KAboutData is provided the dialog will also contain KHelpMenu with
