@@ -4,15 +4,18 @@
  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_TRASHFILTERPROXYMODEL_H
-#define AKONADI_TRASHFILTERPROXYMODEL_H
+#pragma once
 
 #include "akonadicore_export.h"
 
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace Akonadi
 {
+class TrashFilterProxyModelPrivate;
+
 /**
  * @short Filter model which hides/shows entities marked as trash
  *
@@ -52,18 +55,16 @@ public:
 
 protected:
     /**
-     * Sort filter criterias, according to how expensive the operation is
+     * Sort filter criteria, according to how expensive the operation is
      */
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
 private:
     /// @cond PRIVATE
-    class TrashFilterProxyModelPrivate;
-    TrashFilterProxyModelPrivate *const d_ptr;
+    std::unique_ptr<TrashFilterProxyModelPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(TrashFilterProxyModel)
     /// @endcond
 };
 
 }
 
-#endif
