@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONDELETEHANDLER_H_
-#define AKONADI_COLLECTIONDELETEHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -38,4 +37,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
