@@ -4,19 +4,19 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "akonadiwidgets_debug.h"
+#include "collectionutils.h"
 #include "dragdropmanager_p.h"
 #include "specialcollectionattribute.h"
-#include "collectionutils.h"
-#include "akonadiwidgets_debug.h"
 #include <QApplication>
+#include <QDrag>
 #include <QDropEvent>
 #include <QMenu>
-#include <QDrag>
 
 #include <KLocalizedString>
+#include <QMimeData>
 #include <QUrl>
 #include <QUrlQuery>
-#include <QMimeData>
 
 #include "collection.h"
 #include "entitytreemodel.h"
@@ -31,7 +31,7 @@ DragDropManager::DragDropManager(QAbstractItemView *view)
 Akonadi::Collection DragDropManager::currentDropTarget(QDropEvent *event) const
 {
     const QModelIndex index = m_view->indexAt(event->pos());
-    Collection collection = m_view->model()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
+    auto collection = m_view->model()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
     if (!collection.isValid()) {
         const Item item = m_view->model()->data(index, EntityTreeModel::ItemRole).value<Item>();
         if (item.isValid()) {
@@ -57,8 +57,7 @@ bool DragDropManager::dropAllowed(QDragMoveEvent *event) const
         for (const QUrl &url : urls) {
             const Collection collection = Collection::fromUrl(url);
             if (collection.isValid()) {
-                if (!supportedContentTypes.contains(Collection::mimeType()) &&
-                        !supportedContentTypes.contains(Collection::virtualMimeType())) {
+                if (!supportedContentTypes.contains(Collection::mimeType()) && !supportedContentTypes.contains(Collection::virtualMimeType())) {
                     break;
                 }
 
@@ -67,7 +66,7 @@ bool DragDropManager::dropAllowed(QDragMoveEvent *event) const
                     break;
                 }
             } else { // This is an item.
-                const QList<QPair<QString, QString> > query = QUrlQuery(url).queryItems();
+                const QList<QPair<QString, QString>> query = QUrlQuery(url).queryItems();
                 for (int i = 0; i < query.count(); ++i) {
                     if (query.at(i).first == QLatin1String("type")) {
                         const QString type = query.at(i).second;
@@ -132,17 +131,14 @@ bool DragDropManager::processDropEvent(QDropEvent *event, bool &menuCanceled, bo
     bool linkAllowed;
     moveAllowed = copyAllowed = linkAllowed = false;
 
-    if ((targetCollection.rights() & (Collection::CanCreateCollection | Collection::CanCreateItem)) &&
-            (event->possibleActions() & Qt::MoveAction)) {
+    if ((targetCollection.rights() & (Collection::CanCreateCollection | Collection::CanCreateItem)) && (event->possibleActions() & Qt::MoveAction)) {
         moveAllowed = true;
     }
-    if ((targetCollection.rights() & (Collection::CanCreateCollection | Collection::CanCreateItem)) &&
-            (event->possibleActions() & Qt::CopyAction)) {
+    if ((targetCollection.rights() & (Collection::CanCreateCollection | Collection::CanCreateItem)) && (event->possibleActions() & Qt::CopyAction)) {
         copyAllowed = true;
     }
 
-    if ((targetCollection.rights() & Collection::CanLinkItem) &&
-            (event->possibleActions() & Qt::LinkAction)) {
+    if ((targetCollection.rights() & Collection::CanLinkItem) && (event->possibleActions() & Qt::LinkAction)) {
         linkAllowed = true;
     }
 
@@ -153,13 +149,13 @@ bool DragDropManager::processDropEvent(QDropEvent *event, bool &menuCanceled, bo
     }
 
     if (!moveAllowed && !copyAllowed && !linkAllowed) {
-        qCDebug(AKONADIWIDGETS_LOG) << "Cannot drop here:" << event->possibleActions() << m_view->model()->supportedDragActions() << m_view->model()->supportedDropActions();
+        qCDebug(AKONADIWIDGETS_LOG) << "Cannot drop here:" << event->possibleActions() << m_view->model()->supportedDragActions()
+                                    << m_view->model()->supportedDropActions();
         return false;
     }
 
     // first check whether the user pressed a modifier key to select a specific action
-    if ((QApplication::keyboardModifiers() & Qt::ControlModifier) &&
-            (QApplication::keyboardModifiers() & Qt::ShiftModifier)) {
+    if ((QApplication::keyboardModifiers() & Qt::ControlModifier) && (QApplication::keyboardModifiers() & Qt::ShiftModifier)) {
         if (linkAllowed) {
             defaultAction = Qt::LinkAction;
             actionCount = 1;
@@ -211,19 +207,20 @@ bool DragDropManager::processDropEvent(QDropEvent *event, bool &menuCanceled, bo
 
     if (moveAllowed) {
         sequence = QKeySequence(Qt::ShiftModifier).toString();
-        sequence.chop(1);   // chop superfluous '+'
-        moveDropAction = popup.addAction(QIcon::fromTheme(QStringLiteral("go-jump")), i18n("&Move Here") + QLatin1Char('\t') + sequence);
+        sequence.chop(1); // chop superfluous '+'
+        moveDropAction = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-move"), QIcon::fromTheme(QStringLiteral("go-jump"))),
+                                         i18n("&Move Here") + QLatin1Char('\t') + sequence);
     }
 
     if (copyAllowed) {
         sequence = QKeySequence(Qt::ControlModifier).toString();
-        sequence.chop(1);   // chop superfluous '+'
+        sequence.chop(1); // chop superfluous '+'
         copyDropAction = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy Here") + QLatin1Char('\t') + sequence);
     }
 
     if (linkAllowed) {
-        sequence = QKeySequence(Qt::ControlModifier + Qt::ShiftModifier).toString();
-        sequence.chop(1);   // chop superfluous '+'
+        sequence = QKeySequence(Qt::ControlModifier | Qt::ShiftModifier).toString();
+        sequence.chop(1); // chop superfluous '+'
         linkAction = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-link")), i18n("&Link Here") + QLatin1Char('\t') + sequence);
     }
 
@@ -255,14 +252,15 @@ void DragDropManager::startDrag(Qt::DropActions supportedActions)
         }
 
         if (sourceDeletable) {
-            Collection source = index.data(EntityTreeModel::CollectionRole).value<Collection>();
+            auto source = index.data(EntityTreeModel::CollectionRole).value<Collection>();
             if (!source.isValid()) {
                 // index points to an item
                 source = index.data(EntityTreeModel::ParentCollectionRole).value<Collection>();
                 sourceDeletable = source.rights() & Collection::CanDeleteItem;
             } else {
                 // index points to a collection
-                sourceDeletable = (source.rights() & Collection::CanDeleteCollection) && !source.hasAttribute<SpecialCollectionAttribute>() && !source.isVirtual();
+                sourceDeletable =
+                    (source.rights() & Collection::CanDeleteCollection) && !source.hasAttribute<SpecialCollectionAttribute>() && !source.isVirtual();
             }
         }
         indexes.append(index);
@@ -277,7 +275,7 @@ void DragDropManager::startDrag(Qt::DropActions supportedActions)
         return;
     }
 
-    QDrag *drag = new QDrag(m_view);
+    auto drag = new QDrag(m_view);
     drag->setMimeData(mimeData);
     if (indexes.size() > 1) {
         drag->setPixmap(QIcon::fromTheme(QStringLiteral("document-multiple")).pixmap(QSize(22, 22)));
@@ -294,8 +292,7 @@ void DragDropManager::startDrag(Qt::DropActions supportedActions)
     }
 
     Qt::DropAction defaultAction = Qt::IgnoreAction;
-    if ((QApplication::keyboardModifiers() & Qt::ControlModifier) &&
-            (QApplication::keyboardModifiers() & Qt::ShiftModifier)) {
+    if ((QApplication::keyboardModifiers() & Qt::ControlModifier) && (QApplication::keyboardModifiers() & Qt::ShiftModifier)) {
         defaultAction = Qt::LinkAction;
     } else if ((QApplication::keyboardModifiers() & Qt::ControlModifier)) {
         defaultAction = Qt::CopyAction;
